#
#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
#
#
define hdp::java::package()
{
    
  include hdp::params
  
  $security_enabled = $hdp::params::security_enabled
  $jdk_bin = $hdp::params::jdk_name
  $artifact_dir = $hdp::params::artifact_dir
  $jdk_location = $hdp::params::jdk_location
  $jdk_curl_target = "${artifact_dir}/${jdk_bin}"
 
  $java_home = $hdp::params::java64_home
  $java_exec = "${java_home}/bin/java"
  $java_dir = regsubst($java_home,'/[^/]+$','')

  if ($jdk_bin != "") {
    # curl -k - ignoring unverified server ssl sertificate,
    $curl_cmd = "mkdir -p ${artifact_dir} ; curl -kf --retry 10 ${jdk_location}/${jdk_bin} -o ${jdk_curl_target}"
    exec{ "${curl_cmd} ${name}":
      command => $curl_cmd,
      creates => $jdk_curl_target,
      path    => ["/bin","/usr/bin/"],
      unless  => "test -e ${java_exec}"
    }

    if (hdp_str_ends_with($jdk_bin, ".bin")) {
      $install_cmd = "mkdir -p ${java_dir} ; chmod +x ${jdk_curl_target}; cd ${java_dir} ; echo A | ${jdk_curl_target} -noregister > /dev/null 2>&1"
    }
    elsif (hdp_str_ends_with($jdk_bin, ".gz")) {
      $install_cmd = "mkdir -p ${java_dir} ; cd ${java_dir} ; tar -xf ${jdk_curl_target} > /dev/null 2>&1"
    }

    exec{ "${install_cmd} ${name}":
      command => $install_cmd,
      unless  => "test -e ${java_exec}",
      path    => ["/bin","/usr/bin/"]
    }

    exec{ "${java_exec} ${name}":
      command => "test -e ${java_exec}",
      path    => ["/bin","/usr/bin/"]
    }

    if ($security_enabled == true) {
      hdp::java::jce::package{ $name:
        java_home_dir  => $java_home,
        jdk_location => $jdk_location,
        jdk_bin => $jdk_bin
      }
    }

    anchor{"hdp::java::package::${name}::begin":} -> Exec["${curl_cmd} ${name}"] ->  Exec["${install_cmd} ${name}"] -> Exec["${java_exec} ${name}"] ->  anchor{"hdp::java::package::${name}::end":}
    if ($security_enabled == true) {
      Exec["${java_exec} ${name}"] -> Hdp::Java::Jce::Package[$name]
   }
 }
}
